@@ -15,9 +15,9 @@ import pyLinAcc
 import gtk
 import os.path
 import pango
-import accerciser.plugin
+from accerciser.plugin import ViewportPlugin
 from accerciser.icons import getIcon
-from accerciser.i18n import _
+from accerciser.i18n import _, N_
 
 GLADE_FILE = os.path.join(os.path.dirname(__file__), 
                           'interface_view.glade')
@@ -30,15 +30,15 @@ class CallCache(list):
       else:
          return False
 
-class InterfaceViewer(accerciser.plugin.ViewportPlugin):
-  plugin_name = 'Interface viewer'
-  plugin_description = 'Allows viewing of various interfac propertiesXS'
+class InterfaceViewer(ViewportPlugin):
+  plugin_name = N_('Interface Viewer')
+  plugin_description = N_('Allows viewing of various interface properties')
   def init(self):
     self.main_xml = gtk.glade.XML(GLADE_FILE, 'iface_view_frame')
     frame = self.main_xml.get_widget('iface_view_frame')
     self.plugin_area.add(frame)
-
     self.role = self.main_xml.get_widget('role')
+
     self.main_xml.signal_autoconnect(self)
     self._initTreeViews()
 
@@ -137,6 +137,9 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
     self.relation_bg = style.base[gtk.STATE_NORMAL]
     selection = treeview.get_selection()
     selection.set_select_function(self._relationSelectFunc, full=True)
+    show_button = self.main_xml.get_widget('button_relation_show')
+    show_button.set_sensitive(self._isSelectedInView(selection))
+    selection.connect('changed', self._onViewSelectionChanged, show_button)
 
     # configure selection tree view
     treeview = self.main_xml.get_widget('treeview_selection')
@@ -152,6 +155,9 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
     treeview.append_column(tvc)
     # connect selection changed signal
     selection = treeview.get_selection()
+    show_button = self.main_xml.get_widget('button_selection_clear')
+    show_button.set_sensitive(self._isSelectedInView(selection))
+    selection.connect('changed', self._onViewSelectionChanged, show_button)
     selection.connect("changed", self._onSelectionSelected)
 
     # configure states tree view
@@ -203,6 +209,10 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
     tvc.pack_start(crt, True)
     tvc.set_attributes(crt, text=5)
     treeview.append_column(tvc)    
+    selection = treeview.get_selection()
+    show_button = self.main_xml.get_widget('button_hypertext_show')
+    show_button.set_sensitive(self._isSelectedInView(selection))
+    selection.connect('changed', self._onViewSelectionChanged, show_button)
 
     # configure actions tree view
     treeview = self.main_xml.get_widget('treeview_action')
@@ -223,6 +233,10 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
     tvc.pack_start(crt, True)
     tvc.set_attributes(crt, text=3)
     treeview.append_column(tvc)
+    selection = treeview.get_selection()
+    show_button = self.main_xml.get_widget('button_action_do')
+    show_button.set_sensitive(self._isSelectedInView(selection))
+    selection.connect('changed', self._onViewSelectionChanged, show_button)
 
     # configure streamable content tree view
     treeview = self.main_xml.get_widget('treeview_streams')
@@ -283,7 +297,6 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
     selected accessible at the time it was selected. Does not automatically
     update when the accessible changes.
     '''
-    
     try:
       name = acc.name
     except:
@@ -326,6 +339,13 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
     self.role.set_markup('<span size="large" weight="bold">%s</span>' % role_name)
     
   def _setExpanderChildrenSensitive(self, expander, sensitive):
+    label = expander.get_label_widget()
+    label_text = label.get_label()
+    if sensitive:
+      label_text = label_text.replace(_(' (not implemented)'), '')
+    elif _(' (not implemented)') not in label_text:
+      label_text += _(' (not implemented)')
+    label.set_label(label_text)
     for child in expander.get_children():
       child.set_sensitive(sensitive)
 
@@ -340,6 +360,15 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
       return
     pop_func(self.acc)
 
+  def _isSelectedInView(self, selection):
+    model, rows = selection.get_selected_rows()
+    something_is_selected = bool(rows)
+    return something_is_selected
+
+  def _onViewSelectionChanged(self, selection, *widgets):
+    for widget in widgets:
+      widget.set_sensitive(self._isSelectedInView(selection))
+
 ##############################
 # Accessible Interface
 ##############################
@@ -383,7 +412,6 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
         relations_model.append(iter, [getIcon(acc), acc.name, acc])
     relations_view.expand_all()
 
-
   def _relationCellDataFunc(self, tvc, cellrenderer, model, iter):
     if len(model.get_path(iter)) == 1:
       cellrenderer.set_property('cell-background-gdk', self.header_bg)
@@ -410,7 +438,7 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
       acc = model[iter][2]
       if acc:
         self.node.update(acc)
-
+  
   def _accEventState(self, event):
      if self.acc != event.source:
         return
@@ -440,11 +468,20 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
   def _onActionRowActivated(self, treeview, path, view_column):
      actions_model = treeview.get_model()
      iter = actions_model.get_iter(path)
-     action_num = actions_model.get_value(iter, 0)
+     action_num = actions_model[iter][0]
      acc = self.acc
      ai = pyLinAcc.Interfaces.IAction(acc)
      ai.doAction(action_num)
 
+  def _onActionClicked(self, button):
+    actions_view = self.main_xml.get_widget('treeview_action')
+    selection = actions_view.get_selection()
+    actions_model, iter = selection.get_selected()
+    action_num = actions_model[iter][0]
+    acc = self.acc
+    ai = pyLinAcc.Interfaces.IAction(acc)
+    ai.doAction(action_num)
+
 ##############################
 # Application Interface
 ##############################
@@ -537,7 +574,6 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
         if anchor_index == 0:
           links_model[iter][1] = acc_obj.name # Otherwise the link is nameless.
      
-
   def _onLinkShow(self, link_view, *more_args):
     selection = link_view.get_selection()
     model, iter = selection.get_selected()
@@ -593,19 +629,19 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
           selection_model.append([getIcon(child),child.name, child])
 
   def _onSelectionSelected(self, selection):
-     acc = self.acc
-     try:
-        si = pyLinAcc.Interfaces.ISelection(acc)
-     except:
-        return
-     model, paths = selection.get_selected_rows()
-     selected_children = [path[0] for path in paths]
-
-     for child_index in range(len(acc)):
-        if child_index in selected_children:
-           si.selectChild(child_index)
-        else:
-           si.deselectChild(child_index)
+    acc = self.acc
+    try:
+      si = pyLinAcc.Interfaces.ISelection(acc)
+    except:
+      return
+    model, paths = selection.get_selected_rows()
+    selected_children = [path[0] for path in paths]
+    
+    for child_index in range(len(acc)):
+      if child_index in selected_children:
+        si.selectChild(child_index)
+      else:
+        si.deselectChild(child_index)
   
   def _onSelectionClear(self, widget):
      acc = self.acc
@@ -761,14 +797,16 @@ class InterfaceViewer(accerciser.plugin.ViewportPlugin):
       eti = None
 
     expander = self.main_xml.get_widget('expander_text')
-
+    expander_label = expander.get_label_widget()
+    label_text = expander_label.get_label()
+    label_text.replace(_(' <i>(Editable)</i>'),'')
     if eti:
-      expander.set_label('Text <i>(Editable)</i>')
+      label_text += _(' <i>(Editable)</i>')
       text_view.set_editable(True)
     else:
-      expander.set_label('Text')
       text_view.set_editable(False)
-
+    expander_label.set_label(label_text)
+    
   def _attrStringToDict(self, attr_string):
     if not attr_string:
       return {}
